// LICENSE : MIT
"use strict";

/*
 疑問符(?)
 文末に疑問符を使用し、後に別の文が続く場合は、直後に全角スペースを挿入します。
 文中に疑問符を使用する場合はスペースを挿入しません。
 */
var _textlintRuleHelper = require("textlint-rule-helper");
var _matchIndex = require("match-index");
function reporter(context) {
  var {
    Syntax,
    RuleError,
    report,
    fixer,
    getSource
  } = context;
  var helper = new _textlintRuleHelper.RuleHelper();
  return {
    [Syntax.Str](node) {
      if (!helper.isPlainStrNode(node)) {
        return;
      }
      var text = getSource(node);
      // ？の後ろは全角スペースが推奨
      // 半角スペースである場合はエラーとする
      var matchAfter = /？( )[^\n]/;
      (0, _matchIndex.matchCaptureGroupAll)(text, matchAfter).forEach(match => {
        var {
          index
        } = match;
        return report(node, new RuleError("文末に疑問符を使用し、後に別の文が続く場合は、直後に全角スペースを挿入します。", {
          index: index,
          fix: fixer.replaceTextRange([index, index + 1], "　")
        }));
      });
    }
  };
}
module.exports = {
  linter: reporter,
  fixer: reporter
};
//# sourceMappingURL=index.js.map